%{
  Idealised numerical model for equilibrium shapes of tidal sandbanks under sediment-scarce conditions (1D)
  Copyright (C) 2023  Thomas van Veelen. Email: t.j.vanveelen@utwente.nl

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%}

function [Hrock,drock,t,f,r,sema,Uw,Frsquared,gamma,Ldom,k,lambda,gammarel] = VariableScaling_rock(Hstar,Lstar,Hrockstar,drockstar,sigmastar,tstar,...
    Tmorstar,fstar,rstar,semastar,Ustar,Uwstar,gstar,kstar,Ldomstar,lambdastar,gammadeposition)
% subfunction for variable scaling

Hrock = Hrockstar / Hstar;                      % -; Depth of the non-erodible layer
drock = drockstar / Hstar;                      % -; Thickness of the buffer layer.
f = fstar/sigmastar;                            % -; Scaled Coriolis parameter
r = rstar/(sigmastar*Hstar);                    % -; Scaled bottom friction parameter
k = kstar*Lstar;                                % -; Scaled wave number
Ldom = Ldomstar/Lstar;                          % -; Scaled domain length
sema = semastar/Ustar;                          % -; Scaled semimajor axis of tidal flow
Uw = Uwstar/Ustar;                              % -; Scaled wind-driven current velocity scale
Frsquared = Ustar^2/(gstar*Hstar);              % -; Froude number squared
gamma = (sigmastar*Tmorstar)^-1;                % -; Relation tidal and morphological time scale
lambda = lambdastar*Hstar/Lstar/Ustar;                % -; Scaled bed slope coefficient
t = sigmastar*tstar;                            % -; Scaled time (tidal cycle)
gammarel = gammadeposition/sigmastar;           % -; relative deposition coefficient.

end